@@ -26,7 +26,7 @@
 #include "docprop.h"
 #include "document.h"
 
-gcpDocPropDlg::gcpDocPropDlg(gcpDocument* pDoc): gcpDialog(pDoc->GetApplication(), PKGDATADIR"/ui/docprop.glade", "properties")
+gcpDocPropDlg::gcpDocPropDlg(gcpDocument* pDoc): gcpDialog(pDoc->GetApplication(), GLADEDIR"/docprop.glade", "properties")
 {
 	m_pDoc = pDoc;
 	Title = GTK_ENTRY(glade_xml_get_widget(xml, "title"));
