@@ -4,9 +4,7 @@
  * GChemPaint atoms plugin
  * electrontool.h
  *
- * Copyright (C) 2004
- *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Copyright (C) 2004-2005 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -20,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -42,7 +40,7 @@ public:
 private:
 	bool m_bIsPair;
 	double m_dAngle, m_dDistMax, m_dDist;
-	char m_Pos;
+	unsigned char m_Pos;
 };
 
 #endif	//GCHEMPAINT_ELECTRON_TOOL_H
