@@ -4,9 +4,7 @@
  * GChemPaint atoms plugin
  * plugin.cc 
  *
- * Copyright (C) 2004
- *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Copyright (C) 2004 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -20,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -30,6 +28,7 @@
 #include "lib/molecule.h"
 #include "elementtool.h"
 #include "chargetool.h"
+#include "electrontool.h"
 
 gcpAtomsPlugin plugin;
 
@@ -43,8 +42,10 @@ gcpAtomsPlugin::~gcpAtomsPlugin()
 
 void gcpAtomsPlugin::Populate (gcpApplication* App)
 {
-	App->AddUI (DATADIR"/gchempaint/ui/atoms.xml");
+	App->AddUI (GLADEDIR"/atoms.xml");
 	new gcpElementTool (App);
 	new gcpChargeTool (App, "ChargePlus");
 	new gcpChargeTool (App, "ChargeMinus");
+	new gcpElectronTool (App, "ElectronPair");
+	new gcpElectronTool (App, "UnpairedElectron");
 }
